@@ -1,6 +1,6 @@
 # This file is part of pybliographer
 # 
-# Copyright (C) 1998 Frederic GOBRY
+# Copyright (C) 1998,1999,2000 Frederic GOBRY
 # Email : gobry@idiap.ch
 # 	   
 # This program is free software; you can redistribute it and/or
@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Search.py,v 1.1.1.1 1999/11/22 13:29:31 fredgo Exp $
+# $Id: Search.py,v 1.3 2000/03/14 16:05:36 fredgo Exp $
 
 from gnome.ui import *
 from gtk import *
@@ -25,29 +25,18 @@ import GTK
 
 import string, re, sys, traceback, copy
 
-from Pyblio import Types, Search, Config
+from Pyblio import Types, Search, Config, Connector, TextUI
 
 from Pyblio.GnomeUI import Utils
 
-import Pyblio.GnomeUI.Database
-import Pyblio.TextUI
-
 import gettext
 _ = gettext.gettext
 
 
-def popup_add (menu, item, action = None, argument = None):
-    ''' Helper to add a new menu entry '''
-    tmp = GtkMenuItem (item)
-    if action:
-        tmp.connect ('activate', action, argument)
-    tmp.show ()
-    menu.append (tmp)
-    
-    return tmp
-
 class ItemStorage (GtkTreeItem):
-
+    ''' Extension to TreeItem that stores additional information about
+    the search nodes '''
+    
     def __init__ (self, name, data):
         GtkTreeItem.__init__ (self, name)
 
@@ -110,13 +99,16 @@ class ItemStorage (GtkTreeItem):
             if ret: return ret
             
         return None
+
     
-class SearchDialog (GtkDialog):
+class SearchDialog (GtkDialog, Connector.Publisher):
     ''' Search Dialog '''
     
-    def __init__ (self, data):
+    def __init__ (self, parent = None):
 
         GtkDialog.__init__ (self)
+
+        if parent: self.set_transient_for (parent)
         
         self.set_title (_("Search"))
         self.set_usize (400, 500)        
@@ -144,12 +136,6 @@ class SearchDialog (GtkDialog):
         self.notebook = GtkNotebook ()
         self.vbox.pack_start (self.notebook, expand = FALSE, fill = FALSE)
 
-        # status
-        self.status = GtkStatusbar ()
-        self.status.set_border_width (5)
-        
-        self.vbox.pack_start (self.status, expand = FALSE, fill = FALSE)
-        
         # Simple search
         table = GtkTable (2,2)
         table.set_border_width (5)
@@ -168,7 +154,7 @@ class SearchDialog (GtkDialog):
         # fill the combo
         self.field.set_popdown_strings ([' - any field - '] +
                                         list (Config.get
-                                              ('base/searched').data) +
+                                              ('gnomeui/searched').data) +
                                         [' - type - ', ' - key - '])
 
         self.notebook.append_page (table, GtkLabel (_("Simple Search")))
@@ -198,32 +184,29 @@ class SearchDialog (GtkDialog):
         self.root_tree.connect ('button_press_event', self.popup_menu)
 
         self.menu = GtkMenu ()
-        self.delete_button = popup_add (self.menu, _("Delete"),  self.search_delete)
+        self.delete_button = Utils.popup_add (self.menu, _("Delete"),  self.search_delete)
         self.menu.show ()
 
         self.root_item = None
-        self.create_root_item (data)
+        self.create_root_item (None)
+
+        self.show_all ()
         return
 
-    def create_root_item (self, data):
-        self.data = data
 
+    def create_root_item (self, data):
         if self.root_item:
             self.root_item.remove_subtree ()
             self.root_tree.remove (self.root_item)
             
         # initialize the tree with the full database
-        self.root_item = ItemStorage (_("Full database"), self.data.data)
+        self.root_item = ItemStorage (_("Full database"), None)
         self.root_tree.append (self.root_item)
         self.root_item.show ()
-
-        self.status.pop  (1)
-        self.status.push (1, _("Ready to search !"))
         return
     
     
     def apply (self, widget):
-        if self.data.data is None: return
         page = self.notebook.get_current_page ()
 
         name = None
@@ -308,8 +291,6 @@ class SearchDialog (GtkDialog):
         if name is None:
             name = str (test)
             
-        self.status.pop (1)
-
         # get selection
         selection = self.root_tree.get_selection ()
         
@@ -319,16 +300,10 @@ class SearchDialog (GtkDialog):
             selection = selection [0]
 
         selection = self.root_item.search (selection)
-        data = selection.data
-        
-        # actual search
-        Utils.set_cursor (self, 'clock')
-            
-        r = data.where (test)
+        if selection.data:
+            test = selection.data & test
 
-        Utils.set_cursor (self, 'normal')
-
-        item = ItemStorage (name, r)
+        item = ItemStorage (name, test)
         item.show ()
         
         tree = selection.add (item)
@@ -339,11 +314,8 @@ class SearchDialog (GtkDialog):
             selection.expand ()
 
         selection.tree.select_child (item)
-
-        self.status.pop (1)
-        self.status.push (1, _("found %d matches") % len (r))
-
         return
+
     
     def close (self, * arg):
         self.hide ()
@@ -361,16 +333,7 @@ class SearchDialog (GtkDialog):
         
         data = self.root_item.search (selection).data
         
-        if data is None: return
-        
-        if data.key != self.data.data.key:
-            Utils.set_cursor (self, 'clock')
-            self.data.set (data)
-            Utils.set_cursor (self, 'normal')
-            
-            self.status.pop (1)
-            self.status.push (1, _("%d matches in this node") % len (data))
-            
+        self.issue ('search-data', data)
         return
 
     
