@@ -18,7 +18,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: bibtex.h,v 1.1.1.1 1999/11/22 13:29:32 fredgo Exp $
+ $Id: bibtex.h,v 1.3 2000/02/10 09:41:22 fredgo Exp $
 */
 
 #ifndef __bibtex_h__
@@ -122,12 +122,12 @@ extern "C" {
     */
 
     typedef struct {
-	BibtexFieldType    type;
-	BibtexStruct *     structure;
-
 	gboolean converted;
 	gboolean loss;
 
+	BibtexFieldType    type;
+	BibtexStruct *     structure;
+
 	gchar * text;
 
 	union {
@@ -142,14 +142,14 @@ extern "C" {
     */
 
     typedef struct {
-	gchar * type;
-	gchar * name;
-	
 	int length;
 	int offset;
 
 	int start_line;
 
+	gchar * type;
+	gchar * name;
+	
 	BibtexStruct * preamble;
 
 	GHashTable * table;
@@ -168,6 +168,14 @@ extern "C" {
     BibtexSourceType;
 
     typedef struct {
+	gboolean eof, error;
+	gboolean strict;
+
+	int line;
+	int offset;
+
+	int debug;
+
 	BibtexSourceType type;
 
 	gchar * name;
@@ -177,15 +185,8 @@ extern "C" {
 	    gchar * string;
 	} source;
 
-	int line;
-	int offset;
-
 	GHashTable * table;
 	gpointer buffer;
-
-	int debug;
-	gboolean eof, error;
-	gboolean strict;
     }
     BibtexSource;
 
@@ -213,6 +214,15 @@ extern "C" {
 					 gchar * name,
 					 gchar * string);
 
+    /* Manipulate @string definitions in that source */
+    BibtexStruct * bibtex_source_get_string (BibtexSource * source,
+					     gchar * key);
+
+    void           bibtex_source_set_string (BibtexSource * source,
+					     gchar * key,
+					     BibtexStruct * value);
+
+
     BibtexEntry *  bibtex_source_next_entry (BibtexSource * file, gboolean filter);
 
     void           bibtex_source_rewind (BibtexSource * file);
