@@ -18,7 +18,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: reverse.c,v 1.1.1.1 1999/11/22 13:29:32 fredgo Exp $
+ $Id: reverse.c,v 1.5 2000/03/13 13:45:21 fredgo Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -90,7 +90,7 @@ bibtex_reverse_field (BibtexField * field) {
 #ifdef USE_RECODE
     BibtexStruct * s;
     gchar * string, * tmp, c;
-    gboolean has_upper;
+    gboolean has_upper, is_upper;
     gint start, stop, last, i;
     BibtexAuthor * author;
 
@@ -124,7 +124,6 @@ bibtex_reverse_field (BibtexField * field) {
 
     switch (field->type) {
     case BIBTEX_OTHER:
-    case BIBTEX_TITLE:
 	g_return_val_if_fail (field->text != NULL, NULL);
 
 	g_string_truncate (st, 0);
@@ -139,6 +138,56 @@ bibtex_reverse_field (BibtexField * field) {
 	s = text_to_struct (st->str);
 	break;
 
+    case BIBTEX_TITLE:
+	g_return_val_if_fail (field->text != NULL, NULL);
+
+	g_string_truncate (st, 0);
+	
+	tmp = recode_string (request, field->text);
+
+	g_string_append (st, "@preamble{{");
+
+	/* Put the upper cases or the first lower cases between {} */
+	string = tmp;
+	if (* tmp >= 'a' && * tmp <= 'z') {
+	    /* Put the beginning in lower cases */
+	    g_string_append_c (st, '{');
+	    while (* tmp >= 'a' && * tmp <= 'z') {
+		g_string_append_c (st, * tmp);
+		tmp ++;
+	    }
+	    g_string_append_c (st, '}');
+	}
+
+	is_upper = false;
+	while (* tmp) {
+	    if (* tmp >= 'A' && * tmp <= 'Z') {
+		if (! is_upper) {
+		    g_string_append_c (st, '{');
+		    is_upper = true;
+		}
+		g_string_append_c (st, * tmp);
+	    }
+	    else {
+		if (is_upper) {
+		    g_string_append_c (st, '}');
+		    is_upper = false;
+		}
+
+		g_string_append_c (st, * tmp);
+	    }
+	    tmp ++;
+	}
+	if (is_upper) {
+	    g_string_append_c (st, '}');
+	    is_upper = false;
+	}
+	g_free (string);
+	g_string_append (st, "}}");
+	
+	s = text_to_struct (st->str);
+	break;
+
     case BIBTEX_AUTHOR:
 	g_return_val_if_fail (field->field.author != NULL, NULL);
 
@@ -153,19 +202,25 @@ bibtex_reverse_field (BibtexField * field) {
 
 	    g_string_append_c (st, '{');
 	    if (author->last) {
-		g_string_append (st, author->last);
+		tmp = recode_string (request, author->last);
+		g_string_append (st, tmp);
+		g_free (tmp);
 	    }
 
 	    if (author->lineage) {
 		g_string_append (st, "}, {");
-		g_string_append (st, author->lineage);
+		tmp = recode_string (request, author->lineage);
+		g_string_append (st, tmp);
+		g_free (tmp);
 	    }
 	    g_string_append_c (st, '}');
 
 	    if (author->first) {
 		g_string_append (st, ", ");
 		g_string_append_c (st, '{');
-		g_string_append (st, author->first);
+		tmp = recode_string (request, author->first);
+		g_string_append (st, tmp);
+		g_free (tmp);
 		g_string_append_c (st, '}');
 	    }
 	}
