@@ -18,7 +18,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: pybliographer.py,v 1.1.1.1 1999/11/22 13:29:30 fredgo Exp $
+# $Id: pybliographer.py,v 1.3 2000/03/13 12:45:24 fredgo Exp $
 
 version  = "@version@"
 progname = "@package@"
@@ -27,20 +27,27 @@ lib_pybdir  = "@libpyb@"
 data_pybdir = "@datapyb@"
 localedir   = "@localedir@"
 
+import gettext
+	
+gettext.bindtextdomain(progname, localedir)
+gettext.textdomain(progname)
+
+_ = gettext.gettext
 
 def print_version ():
-	print "This is %s, version %s" % (progname, version)
+	print _("This is %s, version %s") % (progname, version)
 
 def copyright ():
-	print """Copyright (C) 1998-1999 Frederic GOBRY
-This is free software with ABSOLUTELY NO WARRANTY.
-For details, type `warranty'."""
+	print 'Copyright (C) 1998-1999 Frederic GOBRY'
+	print _("This is free software with ABSOLUTELY NO WARRANTY.")
+	print _("For details, type `warranty'.")
 
 def warranty ():
 	print_version ()
-	print """Copyright (C) 1998-1999 Frederic GOBRY
-This is free software with ABSOLUTELY NO WARRANTY.
-
+	print 'Copyright (C) 1998-1999 Frederic GOBRY'
+	
+	print _("This is free software with ABSOLUTELY NO WARRANTY.")
+	print """
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
@@ -60,11 +67,6 @@ import sys
 import os
 import getopt, string
 
-import gettext
-	
-gettext.bindtextdomain(progname, localedir)
-gettext.textdomain(progname)
-
 sys.ps1 = 'python > '
 
 sys.path.append (data_pybdir)
@@ -80,7 +82,7 @@ optlist, args = getopt.getopt (sys.argv [1:],
 				'version',
 				'help'])
 
-sys.argv = args
+sys.argv = sys.argv [0:1] + args
 
 quiet = 0
 
@@ -103,7 +105,7 @@ for opt, value in optlist:
 		try:
 			os.stat (value)
 		except os.error:
-			print "%s: error: can't open file `%s'" \
+			print _("%s: error: can't open file `%s'") \
 			      % (progname, value)
 			sys.exit (1)
 		
@@ -116,7 +118,7 @@ for opt, value in optlist:
 
 	if opt == '-h' or opt == '--help':
 		print_version ()
-		print "For help, run %s and type `help' at the prompt" \
+		print _("For help, run %s and type `help' at the prompt") \
 		      % progname
 		sys.exit (0)
 		
@@ -125,7 +127,7 @@ for opt, value in optlist:
 if not quiet:
 	print_version ()
 	copyright ()
-	print "Useful commands:\n	help     to get some help\n	quit     to quit\n"
+	print _("Useful commands:\n	help     to get some help\n	quit     to quit\n")
 
 # ---------- Lire les fichiers de conf
 
@@ -155,7 +157,7 @@ if len (args) > 0 :
 	try:
 		os.stat (filename)
 	except os.error:
-		print "%s: error: can't open file `%s'" % (progname, filename)
+		print _("%s: error: can't open file `%s'") % (progname, filename)
 		sys.exit (1)
 	else:
 		execfile (filename, user_global)
