@@ -19,26 +19,23 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: pybliographic.py,v 1.1.1.1 1999/11/22 13:29:35 fredgo Exp $
+# $Id: pybliographic.py,v 1.4 2000/03/13 13:45:35 fredgo Exp $
 
+import sys
 
-from Pyblio.GnomeUI import Pybliographic
 from gtk import *
-from Pyblio import Base, Config
+from Pyblio.GnomeUI.Pybliographic import Pybliographic
+from Pyblio.Fields import URL
 
-import os
+main = Pybliographic (version)
 
-main = Pybliographic.Pybliographic (version)
-main.show ()
-
-if len (sys.argv) > 1:
-    try:
-        full = os.path.abspath (sys.argv [1])
-    except AttributeError:
-        full = sys.argv [1]
+if len (sys.argv) > 2:
+    for file in sys.argv [2:]:
+        url = URL (file)
         
-    main.open (full)
-    
+        main.open_document (str (url))
+else:
+    main.new_document ()
+
 mainloop ()
 
-
